package com.tappli.android.bitmapsample;

import android.app.Activity;
import android.graphics.drawable.AnimationDrawable;
import android.graphics.drawable.Drawable;
import android.graphics.drawable.TransitionDrawable;
import android.os.Bundle;
import android.view.View;
import android.widget.ImageView;
import android.widget.TextView;

public class MainActivity extends Activity implements View.OnClickListener {
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.main);
		
		// 初期値の設定
		setLevel(5);
		setClip(5000);
		setScale(5000);
	}

	@Override
	public void onClick(View v) {
		switch (v.getId()) {
		// レベルアップ
		case R.id.level_up:
			setLevel(+1);
			break;
		// レベルダウン
		case R.id.level_down:
			setLevel(-1);
			break;
		// 
		case R.id.transition:
			startTransition();
			break;
		// クリッピング
		case R.id.clip_up:
			setClip(+500);
			break;
		// クリッピング
		case R.id.clip_down:
			setClip(-500);
			break;
		// 拡大
		case R.id.scale_up:
			setScale(+500);
			break;
		// 縮小
		case R.id.scale_down:
			setScale(-500);
			break;
		// アニメーションの切り替え
		case R.id.animation_bitmap:
			toggleAnimation();
			break;
		}
	}
	
	/**
	 * レベルを変化させる
	 * @param val 変化量
	 */
	private void setLevel(int val) {
		TextView view = (TextView) findViewById(R.id.level_text);
		Drawable d = view.getBackground();
		int level = d.getLevel() + val;
		if (level < 0 || level > 10) {
			return;
		}
		d.setLevel(level);
		
		view.setText(getString(R.string.level_list_bitmap) + "\nLv:" + level);
	}
	
	/**
	 * トランジションの開始
	 */
	private void startTransition() {
		View view = findViewById(R.id.transition);
		TransitionDrawable d = (TransitionDrawable) view.getBackground();
		d.startTransition(1000);
	}
	
	/**
	 * クリッピングの設定
	 * @param val
	 */
	private void setClip(int val) {
		TextView view = (TextView) findViewById(R.id.clip_text);
		Drawable d = view.getBackground();
		int level = d.getLevel() + val;
		if (level < 0 || level > 10000) {
			return;
		}
		d.setLevel(level);
		
		view.setText(getString(R.string.clip_bitmap) + "\nLv:" + level);
	}
	
	/**
	 * 拡大・縮小の設定
	 * @param val
	 */
	private void setScale(int val) {
		TextView view = (TextView) findViewById(R.id.scale_text);
		Drawable d = view.getBackground();
		int level = d.getLevel() + val;
		if (level < 0 || level > 10000) {
			return;
		}
		d.setLevel(level);
		
		view.setText(getString(R.string.scale_bitmap) + "\nLv:" + level);
	}
	
	private void toggleAnimation() {
		ImageView image = (ImageView) findViewById(R.id.animation_bitmap);
		AnimationDrawable anim = (AnimationDrawable) image.getDrawable();
		
		if (anim.isRunning()) {
			// アニメーションの停止
			anim.stop();
		}
		else {
			// アニメーションの開始
			anim.start();
		}
		
	}
}